translate.filters.autocorrect

Package translate :: Package filters :: Module autocorrect |
[hide private]
[frames] | no frames]

# Module autocorrect

source code

A set of autocorrect functions that fix common punctuation and space problems automatically

Functions | [hide private]
correct(source, target) Runs a set of easy and automatic corrections | source code

Variables | [hide private]
| __package__ = ``'``translate.filters``'``

Imports: decoration, accepts, returns, IsOneOf

Function Details | [hide private]

### correct(source, target) | source code
Runs a set of easy and automatic corrections Current corrections include: Ellipses - align target to use source form of ellipses (either three dots or the Unicode ellipses characters) Missing whitespace and start or end of the target Missing punction (.:?) at the end of the target Decorators: `@accepts(unicode, unicode)` `@returns(IsOneOf(unicode, type(None)))`